#!/usr/bin/env python2
#
# Copyright 3D Control Systems, Inc. All Rights Reserved 2017-2019. Built in San Francisco.
#
# This software is distributed under commercial non-GPL license for personal, educational,
# corporate or any other use. The software as a whole or any parts of that are prohibited
# for distribution and/or use without obtaining license from 3D Control Systems, Inc.
#
# If you do not have the license to use this software, please delete all software files
# immediately and contact sales to obtain the license: sales@3dprinteros.com.
# If you are unsure about the licensing please contact directly our sales: sales@3dprinteros.com.

import gtk

import tray_common

try:
    import notify2 as libnotify
except ImportError:
    try:
        import pynotify as libnotify
    except:
        libnotify = None
if libnotify:
    libnotify.init(tray_common.APP_NAME)
    def show_libnotify_notification(title, body):
        try:
            libnotify.Notification(title, body, tray_common.ICON_PATH).show()
        except:
            def show_libnotify_notification(title, body):
                pass
else:
    def show_libnotify_notification(title, body):
        pass


def show_message(data=None):
    msg = gtk.MessageDialog(None, gtk.DIALOG_MODAL, gtk.MESSAGE_INFO, gtk.BUTTONS_OK, data)
    msg.run()
    msg.destroy()

def open_browser_tab(data):
    tray_common.open_browser_tab()

def quit_response(widget, response_id):
    if response_id == gtk.RESPONSE_YES:
        gtk.main_quit()
        stop_3dprinteros()

def quit(data):
    message = "Are sure you want to quit " + tray_common.APP_NAME + "?"
    msg = gtk.MessageDialog(None, gtk.DIALOG_DESTROY_WITH_PARENT, gtk.MESSAGE_QUESTION, gtk.BUTTONS_YES_NO, message)
    msg.connect("response", quit_response)
    msg.run()
    msg.destroy()

def stop_3dprinteros():
    show_libnotify_notification('Closing ' + tray_common.APP_NAME, ' ')
    tray_common.stop_app()

def make_menu(event_button, event_time, data=None):
    menu = gtk.Menu()
    menu.set_title(tray_common.APP_NAME)
    open_tab_item = gtk.MenuItem("Open browser tab")
    if STATUS_CHECKER.notifications:
        notifications_item = gtk.MenuItem("Disable notifications")
        notifications_func = disable_notifications
    else:
        notifications_item = gtk.MenuItem("Enable notifications")
        notifications_func = enable_notifications
    quit_item = gtk.MenuItem("Quit")
    menu.append(open_tab_item)
    menu.append(notifications_item)
    menu.append(quit_item)
    open_tab_item.connect_object("activate",  open_browser_tab, None)
    notifications_item.connect_object("activate", notifications_func, None)
    quit_item.connect_object("activate", quit, None)
    open_tab_item.show()
    notifications_item.show()
    quit_item.show()
    menu.popup(None, None, None, event_button, event_time)

def disable_notifications(event):
    STATUS_CHECKER.toggle_notifications(False)
    show_libnotify_notification('Notifications disabled',
                                'You can get status by left click on ' + tray_common.APP_NAME + ' icon')

def enable_notifications(event):
    STATUS_CHECKER.toggle_notifications(True)
    show_libnotify_notification('Notifications enable',
                                'Now you will be notified about status changes in real time')

def on_right_click(data, event_button, event_time):
    make_menu(event_button, event_time)

def on_left_click(event):
    STATUS_CHECKER.show_status_balloons()


if __name__ == '__main__':
    STATUS_CHECKER = tray_common.StatusChecker(show_libnotify_notification)
    icon = gtk.status_icon_new_from_file(tray_common.ICON_PATH)
    icon.connect('popup-menu', on_right_click)
    icon.connect('activate', on_left_click)
    gtk.gdk.threads_init()
    gtk.threads_enter()
    try:
        gtk.main()
    except KeyboardInterrupt:
        print 'KeyboardInterrupt received, closing gtk_tray'
    STATUS_CHECKER.stop()
    gtk.threads_leave()