#
# Copyright 3D Control Systems, Inc. All Rights Reserved 2017-2019. Built in San Francisco.
#
# This software is distributed under commercial non-GPL license for personal, educational,
# corporate or any other use. The software as a whole or any parts of that are prohibited
# for distribution and/or use without obtaining license from 3D Control Systems, Inc.
#
# If you do not have the license to use this software, please delete all software files
# immediately and contact sales to obtain the license: sales@3dprinteros.com.
# If you are unsure about the licensing please contact directly our sales: sales@3dprinteros.com.

import paths
paths.init_path_to_libs()
import rumps
import AppKit
import tray_common

class TaskBarIcon(rumps.App):

    def __init__(self):
        self.status_checker = tray_common.StatusChecker(self.show_balloon)
        rumps.App.__init__(self, tray_common.APP_NAME, icon=tray_common.ICON_PATH, quit_button=None)
        DisableItem = rumps.MenuItem("Disable notifications", callback=self.toggle_notifications)
        DisableItem.state = not self.status_checker.notifications
        self._menu.add(rumps.MenuItem("Show status", callback=self.show_status_balloons))
        self._menu.add(rumps.MenuItem('Open browser tab', callback=self.open_browser_tab))
        self._menu.add(DisableItem)
        self._menu.add(rumps.MenuItem('Quit', callback=self.quit))

    def show_balloon(self, title, body):
        rumps.notification(tray_common.APP_NAME, title, body, sound=False)

    def show_status_balloons(self, _):
        self.status_checker.show_status_balloons()

    def open_browser_tab(self, _):
        tray_common.open_browser_tab()

    def toggle_notifications(self, sender):
        sender.state = not sender.state
        self.status_checker.toggle_notifications(not sender.state)

    def quit(self, _):
        tray_common.stop_app()
        self.status_checker.stop()
        rumps.quit_application()

if __name__ == "__main__":
    info = AppKit.NSBundle.mainBundle().infoDictionary()
    info["LSBackgroundOnly"] = "1"
    tray_icon = TaskBarIcon()
    tray_icon.run()